@@ -1,11 +1,6 @@
 import pyperclip
 import os
 
-def available_templates():
-    available = ["union_find", "trie"]
-
-    return available
-    
 def union_find():
     curr_path = os.path.dirname(__file__)
     file_path = os.path.join(curr_path, './union_find.py')
@@ -28,3 +23,10 @@ def trie():
     f.close()
     pyperclip.copy(trie_code)
     return trie_code
+
+def get_available_templates():
+    arr = []
+    arr.append('union_find')
+    arr.append('trie')
+    print(arr)
+    return arr
\ No newline at end of file
